summaryrefslogtreecommitdiff
path: root/src/make.bash
diff options
context:
space:
mode:
authorGustavo Niemeyer <gustavo@niemeyer.net>2012-03-02 02:45:01 -0300
committerGustavo Niemeyer <gustavo@niemeyer.net>2012-03-02 02:45:01 -0300
commit676c9c408827191ecc604b4c6ab250860e5c8fc9 (patch)
treef2d78e0539e3260db675a76a9238948542ddc35e /src/make.bash
parentb3cf43e5236178c53b76b09e5941cf348e751c6a (diff)
downloadgo-676c9c408827191ecc604b4c6ab250860e5c8fc9.tar.gz
build: add GO_ prefix to LDFLAGS and GCFLAGS
Build environments will often define stock LDFLAGS that are not compatible with the gc ld, causing non-obvious failures midway through the build. R=golang-dev, rsc, minux.ma, rsc CC=golang-dev http://codereview.appspot.com/5724044
Diffstat (limited to 'src/make.bash')
-rwxr-xr-xsrc/make.bash20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/make.bash b/src/make.bash
index 8b249ca3b..aaee75e46 100755
--- a/src/make.bash
+++ b/src/make.bash
@@ -17,10 +17,10 @@
#
# GOOS: The target operating system for installed packages and tools.
#
# GCFLAGS: Additional 5g/6g/8g arguments to use when
# building the packages and commands.
#
# LDFLAGS: Additional 5l/6l/8l arguments to use when
# building the packages and commands.
#
# CGO_ENABLED: Setting this to 0 disables the use of cgo
@@ -89,11 +89,11 @@ echo
if [ "$1" = "--dist-tool" ]; then
# Stop after building dist tool.
- mkdir -p $GOTOOLDIR
+ mkdir -p "$GOTOOLDIR"
if [ "$2" != "" ]; then
cp cmd/dist/dist "$2"
fi
- mv cmd/dist/dist $GOTOOLDIR/dist
+ mv cmd/dist/dist "$GOTOOLDIR"/dist
exit 0
fi
@@ -104,23 +104,23 @@ if [ "$1" = "--no-clean" ]; then
fi
./cmd/dist/dist bootstrap $buildall -v # builds go_bootstrap
# Delay move of dist tool to now, because bootstrap may clear tool directory.
-mv cmd/dist/dist $GOTOOLDIR/dist
-$GOTOOLDIR/go_bootstrap clean -i std
+mv cmd/dist/dist "$GOTOOLDIR"/dist
+"$GOTOOLDIR"/go_bootstrap clean -i std
echo
if [ "$GOHOSTARCH" != "$GOARCH" -o "$GOHOSTOS" != "$GOOS" ]; then
echo "# Building packages and commands for host, $GOHOSTOS/$GOHOSTARCH."
GOOS=$GOHOSTOS GOARCH=$GOHOSTARCH \
- $GOTOOLDIR/go_bootstrap install -gcflags "$GCFLAGS" -ldflags "$LDFLAGS" -v std
+ "$GOTOOLDIR"/go_bootstrap install -gcflags "$GO_GCFLAGS" -ldflags "$GO_LDFLAGS" -v std
echo
fi
echo "# Building packages and commands for $GOOS/$GOARCH."
-$GOTOOLDIR/go_bootstrap install -gcflags "$GCFLAGS" -ldflags "$LDFLAGS" -v std
+"$GOTOOLDIR"/go_bootstrap install -gcflags "$GO_GCFLAGS" -ldflags "$GO_LDFLAGS" -v std
echo
-rm -f $GOTOOLDIR/go_bootstrap
+rm -f "$GOTOOLDIR"/go_bootstrap
if [ "$1" != "--no-banner" ]; then
- $GOTOOLDIR/dist banner
+ "$GOTOOLDIR"/dist banner
fi
@@ -17,10 +17,10 @@
# GOOS: The target operating system for installed packages and tools.
#
-# GCFLAGS: Additional 5g/6g/8g arguments to use when
+# GO_GCFLAGS: Additional 5g/6g/8g arguments to use when
# building the packages and commands.
#
@@ -17,10 +17,10 @@
# building the packages and commands.
#
-# LDFLAGS: Additional 5l/6l/8l arguments to use when
+# GO_LDFLAGS: Additional 5l/6l/8l arguments to use when
# building the packages and commands.
#